summaryrefslogtreecommitdiff
path: root/include/http_main.h
diff options
context:
space:
mode:
authorDoug MacEachern <dougm@apache.org>2000-08-02 05:27:38 +0000
committerDoug MacEachern <dougm@apache.org>2000-08-02 05:27:38 +0000
commit059d8dd2122f0a3948c2c09549159f0931a6f236 (patch)
tree8a2937938ed4eec31f918c6c8401ce07012cd37a /include/http_main.h
parent3ae78ff3833de9187e9fc0eb6aab69a8b8162c5a (diff)
downloadhttpd-059d8dd2122f0a3948c2c09549159f0931a6f236.tar.gz
prefix libapr functions and types with apr_
git-svn-id: https://svn.apache.org/repos/asf/httpd/httpd/trunk@85976 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'include/http_main.h')
-rw-r--r--include/http_main.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/include/http_main.h b/include/http_main.h
index f23675bd18..2ab757764f 100644
--- a/include/http_main.h
+++ b/include/http_main.h
@@ -60,7 +60,7 @@
#define APACHE_HTTP_MAIN_H
/* AP_SERVER_BASEARGS is the command argument list parsed by http_main.c
* in ap_getopt() format. Use this for default'ing args that the MPM
* can safely ignore and pass on from its rewrite_args() handler.
*/
#define AP_SERVER_BASEARGS "C:c:D:d:f:vVlLth?"
@@ -73,9 +73,9 @@ extern API_VAR_EXPORT const char *ap_server_argv0;
extern API_VAR_EXPORT const char *ap_server_root;
/* for -C, -c and -D switches */
-extern API_VAR_EXPORT ap_array_header_t *ap_server_pre_read_config;
-extern API_VAR_EXPORT ap_array_header_t *ap_server_post_read_config;
-extern API_VAR_EXPORT ap_array_header_t *ap_server_config_defines;
+extern API_VAR_EXPORT apr_array_header_t *ap_server_pre_read_config;
+extern API_VAR_EXPORT apr_array_header_t *ap_server_post_read_config;
+extern API_VAR_EXPORT apr_array_header_t *ap_server_config_defines;
#ifdef __cplusplus
}
@@ -60,7 +60,7 @@
#define APACHE_HTTP_MAIN_H
/* AP_SERVER_BASEARGS is the command argument list parsed by http_main.c
- * in ap_getopt() format. Use this for default'ing args that the MPM
+ * in apr_getopt() format. Use this for default'ing args that the MPM
* can safely ignore and pass on from its rewrite_args() handler.
*/